@@ -1,4 +1,4 @@
-# Copyright 2014, Paul Johnson (paul@pjcj.net)
+# Copyright 2014-2015, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,7 +10,7 @@ package Devel::Cover::Collection;
 use 5.16.0;
 use warnings;
 
-our $VERSION = '1.17'; # VERSION
+our $VERSION = '1.18'; # VERSION
 
 use Devel::Cover::DB;
 use Devel::Cover::DB::IO::JSON;
@@ -258,11 +258,11 @@ sub write_json {
             $results->{$name}{$version}{coverage}{total} = {
                 map { $_ => $m->{$_}{pc} }
                 grep $m->{$_}{pc} ne 'n/a',
-                grep !/link|module/,
+                grep !/link|log|module/,
                 keys %$m
             };
         } else {
-            print "Cannot process $module: ", Dumper $m;
+            print "Cannot process $module: ", Dumper $m if $self->verbose;
         }
     };
     # print Dumper $vars, $results;
@@ -294,8 +294,9 @@ sub generate_html {
 
     my $vars = {
         title    => "Coverage report",
-        modules  => [],
+        modules  => {},
         vals     => {},
+        subdir   => "latest/",
         headers  => [ grep !/path|time/,
                            @Devel::Cover::DB::Criteria_short, "total" ],
         criteria => [ grep !/path|time/,
@@ -306,10 +307,11 @@ sub generate_html {
     my @modules = sort grep !/^\./, readdir $dh;
     closedir $dh or die "Can't closedir $d: $!";
 
+    my $n = 0;
     for my $module (@modules) {
         my $cover = "$d/$module/cover.json";
         next unless -e $cover;
-        say "Adding $module";
+        say "Adding $module" if $self->verbose;
 
         my $io   = Devel::Cover::DB::IO::JSON->new;
         my $json = $io->read($cover);
@@ -324,11 +326,12 @@ sub generate_html {
             $mod->{name}    //= $name;
             $mod->{version} //= $version;
         }
-        push @{$vars->{modules}}, $mod;
+        my $start = uc substr $module, 0, 1;
+        push @{$vars->{modules}{$start}}, $mod;
 
         my $m = $vars->{vals}{$module} = {};
         $m->{module} = $mod;
-        $m->{link}   = "$module/index.html"
+        $m->{link}   = "/$module/index.html"
             if $json->{summary}{Total}{total}{total};
 
         for my $criterion (@{$vars->{criteria}}) {
@@ -341,7 +344,22 @@ sub generate_html {
             $m->{$criterion}{details} =
                 ($summary->{covered} || 0) . " / " . ($summary->{total} || 0);
         }
+
+        print "." if !($n++ % 1000) && !$self->verbose;
     }
+
+    $n = 0;
+    for my $file (@modules) {
+        # say "looking at [$file]";
+        my ($module) = $file =~ /^ \w - \w\w - \w+ - (.*)
+                                 \. (?: zip | tgz | (?: tar \. (?: gz | bz2 )))
+                                 -- \d{10,11} \. \d{6} \. out \. gz $/x
+          or next;
+        # say "found at [$module]";
+        $vars->{vals}{$module}{log} = $file;
+        print "-" if !($n++ % 1000) && !$self->verbose;
+    }
+
     # print "vars ", Dumper $vars;
 
     $self->write_stylesheet;
@@ -351,10 +369,17 @@ sub generate_html {
         ],
     });
     $template->process("summary", $vars, $f) or die $template->error;
+    for my $start (sort keys %{$vars->{modules}}) {
+        $vars->{module_start} = $start;
+        my $dist = "$d/dist/$start.html";
+        $template->process("module_by_start", $vars, $dist)
+            or die $template->error;
+    }
 
+    # print Dumper $vars;
     $self->write_json($vars);
 
-    say "Wrote collection output to $f";
+    say "\nWrote collection output to $f";
 }
 
 sub local_build {
@@ -428,10 +453,10 @@ sub cover_modules {
                               =~ s/\.(?:zip|tgz|(?:tar\.(?:gz|bz2)))$//r;
             if ($self->is_covered($dir)) {
                 $self->set_covered($dir);
-                say "$module already covered";
+                say "$module already covered" if $self->verbose;
                 return;
             } elsif ($self->is_failed($dir)) {
-                say "$module already failed";
+                say "$module already failed" if $self->verbose;
                 return;
             }
 
@@ -471,7 +496,7 @@ sub get_latest {
 
     require CPAN::Releases::Latest;
 
-    my $latest   = CPAN::Releases::Latest->new;
+    my $latest   = CPAN::Releases::Latest->new(max_age => 0);  # no caching
     my $iterator = $latest->release_iterator;
 
     while (my $release = $iterator->next_release) {
@@ -585,7 +610,7 @@ package Devel::Cover::Collection::Template::Provider;
 use strict;
 use warnings;
 
-our $VERSION = '1.17'; # VERSION
+our $VERSION = '1.18'; # VERSION
 
 use base "Template::Provider";
 
@@ -622,7 +647,7 @@ $Templates{html} = <<'EOT';
 <html xmlns="http://www.w3.org/1999/xhtml">
 <!--
 This file was generated by Devel::Cover Version $VERSION
-Devel::Cover is copyright 2001-2014, Paul Johnson (paul\@pjcj.net)
+Devel::Cover is copyright 2001-2015, Paul Johnson (paul\@pjcj.net)
 Devel::Cover is free. It is licensed under the same terms as Perl itself.
 The latest version of Devel::Cover should be available from my homepage:
 http://www.pjcj.net
@@ -631,11 +656,29 @@ http://www.pjcj.net
 <head>
     <meta http-equiv="Content-Type" content="text/html; charset=utf-8"></meta>
     <meta http-equiv="Content-Language" content="en-us"></meta>
-    <link rel="stylesheet" type="text/css" href="collection.css"></link>
+    <link rel="stylesheet" type="text/css" href="/[% subdir %]collection.css"></link>
     <title> [% title %] </title>
 </head>
 <body>
     [% content %]
+    <p/>
+    <hr/>
+    Coverage information from <a href="https://metacpan.org/module/Devel::Cover">
+      Devel::Cover
+    </a> by <a href="http://pjcj.net">Paul Johnson</a>.
+
+    <br/>
+
+    Please report problems with this site to the
+    <a href="https://github.com/pjcj/Devel--Cover/issues">issue tracker</a>.
+
+    <br/>
+    <br/>
+
+    This server generously donated by
+    <a href="http://www.bytemark.co.uk/r/cpancover">
+      <img src="http://www.bytemark.co.uk/images/subpages/spreadtheword/bytemark_logo_179_x_14.png" alt="bytemark"/>
+    </a>
 </body>
 </html>
 EOT
@@ -643,26 +686,48 @@ EOT
 $Templates{summary} = <<'EOT';
 [% WRAPPER html %]
 
-<h1> [% title %] </h1>
+<h1> CPANCover </h1>
+
+<h2> Distributions </h2>
+
+Search for distributions by first character:<p/>
+
+[% FOREACH start = modules.keys.sort %]
+    <a href="dist/[%- start -%].html">[% start %]</a>
+[% END %]
+
+<h2> Core coverage </h2>
+
+<a href="http://cpancover.com/blead/latest/coverage.html">Perl core coverage</a>
+(under development)
+
+[% END %]
+EOT
+
+$Templates{module_by_start} = <<'EOT';
+[% WRAPPER html %]
+
+<h1> [% title %] - [% module_start %] </h1>
 
 <table>
 
-    [% IF modules %]
+    [% IF modules.$module_start %]
         <tr align="right" valign="middle">
             <th class="header" align="left" style='white-space: nowrap;'> Module </th>
-            <th class="header">              Version </th>
+            <th class="header"> Version </th>
+            <th class="header"> Log </th>
             [% FOREACH header = headers %]
                 <th class="header"> [% header %] </th>
             [% END %]
         </tr>
     [% END %]
 
-    [% FOREACH module = modules %]
+    [% FOREACH module = modules.$module_start %]
         [% m = module.module %]
         <tr align="right" valign="middle">
             <td align="left">
                 [% IF vals.$m.link %]
-                    <a href="[%- vals.$m.link -%]">
+                    <a href="/[% subdir %][%- vals.$m.link -%]">
                         [% module.name || module.module %]
                     </a>
                 [% ELSE %]
@@ -670,6 +735,7 @@ $Templates{summary} = <<'EOT';
                 [% END %]
             </td>
             <td> [% module.version %] </td>
+            <td> <a href="/[% subdir %][% vals.$m.log %]"> &para; </a> </td>
             [% FOREACH criterion = criteria %]
                 <td class="[%- vals.$m.$criterion.class -%]"
                     title="[%- vals.$m.$criterion.details -%]">
@@ -683,28 +749,6 @@ $Templates{summary} = <<'EOT';
 
 <br/>
 
-<hr/>
-Coverage information from <a href="https://metacpan.org/module/Devel::Cover">
-  Devel::Cover
-</a> by <a href="http://pjcj.net">Paul Johnson</a>.
-
-<br/>
-
-Please report problems with this site to the
-<a href="https://github.com/pjcj/Devel--Cover/issues">issue tracker</a>
-
-<br/>
-<a href="http://cpancover.com/blead/latest/coverage.html">Core coverage</a>
-(under development)
-
-<br/>
-<br/>
-
-This server generously donated by
-<a href="http://www.bytemark.co.uk/r/cpancover">
-  <img src="http://www.bytemark.co.uk/images/subpages/spreadtheword/bytemark_logo_179_x_14.png" alt="bytemark"/>
-</a>
-
 [% END %]
 EOT
 
@@ -721,7 +765,7 @@ Devel::Cover::Collection - Code coverage for a collection of modules
 
 =head1 VERSION
 
-version 1.17
+version 1.18
 
 =head1 SYNOPSIS
 
@@ -737,7 +781,7 @@ Almost certainly.
 
 =head1 LICENCE
 
-Copyright 2014, Paul Johnson (paul@pjcj.net)
+Copyright 2014-2015, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
