@@ -1,4 +1,4 @@
-# Copyright 2001-2014, Paul Johnson (paul@pjcj.net)
+# Copyright 2001-2015, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,14 +10,14 @@ package Devel::Cover::Report::Html_basic;
 use strict;
 use warnings;
 
-our $VERSION = '1.16'; # VERSION
+our $VERSION = '1.18'; # VERSION
 our $LVERSION = do { eval '$VERSION' || "0.001" };  # for development purposes
 
 use Devel::Cover::DB;
 use Devel::Cover::Html_Common "launch";
 use Devel::Cover::Web "write_file";
 
-use CGI;
+use HTML::Entities;
 use Getopt::Long;
 use Template 2.00;
 
@@ -217,6 +217,19 @@ sub print_file {
     }
     close F or die "Unable to close $R{file}: $!";
 
+    # Add forward references to uncovered lines ...
+    # first line has a ref to the first uncovered line unless
+    # the first line already is uncovered in which case it links
+    # to the *next* uncovered line
+    {  my @unc = grep { $_->{criteria}[0]{class} eq "c0" &&
+                         $_->{criteria}[0]{text}  eq  "0" } @lines;
+       while (@unc) {
+           my $u = pop @unc;
+           my $link = "#" . $u->{number};
+           (@unc ? $unc[-1] : $lines[0])->{criteria}[0]{link} ||= $link;
+       }
+    }
+
     my $vars = {
         R     => \%R,
         lines => \@lines,
@@ -291,7 +304,7 @@ sub print_conditions {
     my @types = map
                 {
                     name       => do { my $n = $_; $n =~ s/_/ /g; $n },
-                    headers    => [ map { CGI::escapeHTML($_) }
+                    headers    => [ map { encode_entities($_) }
                                     @{$r{$_}[0]{condition}->headers || []} ],
                     conditions => $r{$_},
                 }, sort keys %r;
@@ -432,7 +445,7 @@ package Devel::Cover::Report::Html_basic::Template::Provider;
 use strict;
 use warnings;
 
-our $VERSION = '1.16'; # VERSION
+our $VERSION = '1.18'; # VERSION
 
 use base "Template::Provider";
 
@@ -451,7 +464,7 @@ $Templates{html} = <<'EOT';
      "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml">
 <!--
-This file was generated by Devel::Cover Version [% version %]
+This file was generated by Devel::Cover Version [% R.version %]
 Devel::Cover is copyright 2001-2012, Paul Johnson (paul@pjcj.net)
 Devel::Cover is free. It is licensed under the same terms as Perl itself.
 The latest version of Devel::Cover should be available from my homepage:
@@ -791,7 +804,7 @@ Devel::Cover::Report::Html_basic - HTML backend for Devel::Cover
 
 =head1 VERSION
 
-version 1.16
+version 1.18
 
 =head1 SYNOPSIS
 
@@ -820,7 +833,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2001-2014, Paul Johnson (paul@pjcj.net)
+Copyright 2001-2015, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
